%define debug_package %{nil}

%global _python_bytecompile_extra 0

%global __requires_exclude perl\\(Exporter\\)|perl\\(XSLoader\\)

%define with_docs 1

Summary:	A framework for configuring, compiling and installing applications
Name:		waf
Version:	2.0.21
Release:	%mkrel 1
License:	BSD and Python
Group:		Development/Tools
Url:		https://waf.io/
# Original tarfile can be found at
# https://waf.io/waf-%%{version}.tar.bz2
# We remove docs/book, as this is under CC-BY-NC-ND, which is not
# allowed in Mageia.
# We remove Waf logos ./docs/gfx/waflogo.svg ./docs/slides/presentation/gfx/waflogo.svg ./docs/sphinx/_images/waf-64x64.png
# - Waf logos, licensed CC BY-NC
Source0:	waf-%{version}.stripped.tar.xz
Source1:        macros.waf
Source3:	repack.sh
Patch0:		waf-1.8.11-libdir.patch
Patch1:		waf-1.6.9-logo.patch
Patch2:		waf-1.8.11-sphinx-no-W.patch
Patch3:		pyext-linking.patch
BuildArch:	noarch
BuildRequires:	pkgconfig(python3)
%if %{with_docs}
BuildRequires:	python3dist(sphinx)
BuildRequires:	graphviz
BuildRequires:	imagemagick
Recommends:	%{name}-doc
%endif
BuildConflicts:	waf
Requires:       python(abi) = %{python3_version}
Provides:       waf-python3 = %{version}-%{release}
Obsoletes:      waf-python3 < 2.0.18-2

%description
Waf is a Python-based framework for configuring, compiling and installing
applications. It derives from the concepts of other build tools such as
Scons, Autotools, CMake, and Ant.

%if %{with_docs}
%package -n %{name}-doc
Summary:	Documentation for %{name}
Group:		Documentation

%description -n %{name}-doc
Waf is a Python-based framework for configuring, compiling and
installing applications. It is a replacement for other tools such as
Autotools, Scons, CMake or Ant.
This package contains the HTML documentation for %{name}.
%endif

%prep
%setup -q
%autopatch -p1

# remove BOM, causes trouble later
sed -i -e '1s/^\xEF\xBB\xBF//' waflib/extras/dpapi.py

# add missing quotes, see rhbz#914566 and
# https://code.google.com/p/waf/issues/detail?id=1263
sed -i -e 's@fontname=\(Vera.*sans\),@fontname="\1",@g' \
	docs/sphinx/conf.py \
	docs/sphinx/coremodules.rst \
	docs/sphinx/featuremap.rst

%build
extras=
for f in waflib/extras/*.py ; do
	f=$(basename "$f" .py);
	if [ "$f" != "__init__" ]; then
		extras="${extras:+$extras,}$f" ;
	fi
done
%{__python3} ./waf-light --make-waf --strip --tools="$extras"

%if %{with_docs}
# build html docs
pushd docs/sphinx
../../waf configure build
popd
%endif

%install
# use waf so it unpacks itself
mkdir -p _temp
pushd _temp
  cp -av ../waf .
  %{__python3} ./waf >/dev/null 2>&1
  pushd .waf3-%{version}-*
    find . -name '*.py' -printf '%%P\0' |
	xargs -0 -I{} install -m 0644 -p -D {} %{buildroot}%{_datadir}/waf3/{}
  popd
popd

install -m 0755 -p -D waf-light %{buildroot}%{_bindir}/waf-%{python3_version}

ln -s waf-%{python3_version} %{buildroot}%{_bindir}/waf

# remove shebangs from and fix EOL for all scripts in wafadmin
find %{buildroot}%{_datadir}/ -name '*.py' \
	-exec sed -i -e '1{/^#!/d}' -e 's|\r$||g' {} \;

# fix waf script shebang line
sed -i "1c#! %{__python3}" %{buildroot}%{_bindir}/waf-%{python3_version}

# remove x-bits from everything going to doc
find demos utils -type f -exec chmod 0644 {} \;

# remove hidden file
rm -f docs/sphinx/build/html/.buildinfo

# install waf rpm macro helper
install -D %{SOURCE1} %{buildroot}%{_rpmmacrodir}/macros.waf

# do byte compilation
%py_byte_compile %{__python3} %{buildroot}%{_datadir}/waf3

%if %{with_docs}
%files -n %{name}-doc
%doc docs/sphinx/build/html
%doc README* ChangeLog demos
%endif

%files
%{_rpmmacrodir}/macros.waf
%{_bindir}/%{name}
%{_bindir}/%{name}-%{python3_version}
%{_datadir}/waf3/


%changelog
* Fri Nov 20 2020 kekepower <kekepower> 2.0.21-1.mga8
+ Revision: 1647893
- Update to version 2.0.21

* Sat Apr 04 2020 kekepower <kekepower> 2.0.20-1.mga8
+ Revision: 1564275
- Update to version 2.0.20

* Tue Feb 18 2020 umeabot <umeabot> 2.0.19-2.mga8
+ Revision: 1539224
- Mageia 8 Mass Rebuild
+ wally <wally>
- update url
- update waf rpm macros

* Wed Dec 04 2019 kekepower <kekepower> 2.0.19-1.mga8
+ Revision: 1464169
- Update to version 2.0.19

* Thu Sep 19 2019 wally <wally> 2.0.18-4.mga8
+ Revision: 1443856
- update waf rpm macros (some pkg builds might fail now as waf macros were changed to be more consistent with other similar macros
- install rpm macros to /usr/lib/rpm/macros.d/

* Thu Sep 19 2019 wally <wally> 2.0.18-3.mga8
+ Revision: 1443833
- add patch to fix linking with python3.8 and our LDFLAGS when checking pyext builds

* Sun Sep 15 2019 wally <wally> 2.0.18-2.mga8
+ Revision: 1441061
- rebuild for python3.8
- drop python2 support

* Tue Jul 16 2019 kekepower <kekepower> 2.0.18-1.mga8
+ Revision: 1421859
- Update to version 2.0.18

* Sun Jun 30 2019 kekepower <kekepower> 2.0.17-1.mga8
+ Revision: 1416313
- Update to version 2.0.17

* Thu May 23 2019 kekepower <kekepower> 2.0.16-1.mga7
+ Revision: 1398993
- Update to version 2.0.16

* Mon Mar 11 2019 kekepower <kekepower> 2.0.15-1.mga7
+ Revision: 1373934
- Update to version 2.0.15

* Thu Jan 10 2019 daviddavid <daviddavid> 2.0.14-2.mga7
+ Revision: 1354081
- rebuild for new Python 3.7

* Sun Dec 23 2018 kekepower <kekepower> 2.0.14-1.mga7
+ Revision: 1344753
- Update to version 2.0.14

* Mon Dec 10 2018 kekepower <kekepower> 2.0.13-1.mga7
+ Revision: 1339763
- Update to version 2.0.13

* Thu Oct 11 2018 kekepower <kekepower> 2.0.12-2.mga7
+ Revision: 1319414
- Update to version 2.0.12

* Fri Sep 21 2018 umeabot <umeabot> 2.0.11-2.mga7
+ Revision: 1291997
- Mageia 7 Mass Rebuild

* Wed Sep 12 2018 kekepower <kekepower> 2.0.11-1.mga7
+ Revision: 1258742
- Update to version 2.0.11

* Wed May 23 2018 kekepower <kekepower> 2.0.8-1.mga7
+ Revision: 1231862
- Update to version 2.0.8

* Mon May 07 2018 kekepower <kekepower> 2.0.7-1.mga7
+ Revision: 1227207
- Update to version 2.0.7

* Wed Feb 21 2018 kekepower <kekepower> 1.9.15-2.mga7
+ Revision: 1203956
- Stripped source of files with wrong license
- BR python-sphinx if build with docs

* Wed Feb 21 2018 kekepower <kekepower> 1.9.15-1.mga7
+ Revision: 1203888
- Update to version 1.9.15
- Use pythonegg to include py modules
- Fixed file list

* Fri Aug 04 2017 philippem <philippem> 1.8.19-2.mga7
+ Revision: 1134774
- rebuild for Python3.6

* Tue Feb 16 2016 philippem <philippem> 1.8.19-1.mga6
+ Revision: 962674
- fix doc files list
- update to 1.8.19

* Sat Oct 31 2015 philippem <philippem> 1.8.16-1.mga6
+ Revision: 896980
- update to 1.8.16

* Wed Oct 07 2015 daviddavid <daviddavid> 1.8.12-2.mga6
+ Revision: 886857
- use new python macros
+ tv <tv>
- rebuild for python 3.5

* Fri Aug 28 2015 philippem <philippem> 1.8.12-1.mga6
+ Revision: 870605
- update to 1.8.12
+ eatdirt <eatdirt>
- Upgrade to version 1.8.9

* Wed Oct 15 2014 umeabot <umeabot> 1.7.16-5.mga5
+ Revision: 743151
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.7.16-4.mga5
+ Revision: 730719
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.7.16-3.mga5
+ Revision: 690261
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes
- s/uggests:/Recommends:/

* Sat May 31 2014 pterjan <pterjan> 1.7.16-2.mga5
+ Revision: 629218
- Rebuild for new Python

* Sun Mar 30 2014 philippem <philippem> 1.7.16-1.mga5
+ Revision: 610463
- update to 1.7.16

* Sat Mar 08 2014 philippem <philippem> 1.7.15-1.mga5
+ Revision: 601339
- update to 1.7.15

* Sat Oct 19 2013 umeabot <umeabot> 1.7.13-2.mga4
+ Revision: 534730
- Mageia 4 Mass Rebuild

* Fri Sep 13 2013 philippem <philippem> 1.7.13-1.mga4
+ Revision: 478677
- Update to 1.7.13.

* Wed Jul 03 2013 philippem <philippem> 1.7.11-2.mga4
+ Revision: 449996
+ rebuild (emptylog)

* Wed Jul 03 2013 philippem <philippem> 1.7.11-1.mga4
+ Revision: 449896
- update to 1.7.11

* Mon Mar 25 2013 philippem <philippem> 1.7.10-1.mga3
+ Revision: 405242
- update to new upstream, regression fix, python3_waf macro fix

* Mon Jan 14 2013 umeabot <umeabot> 1.7.8-2.mga3
+ Revision: 385590
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 23 2012 philippem <philippem> 1.7.8-1.mga3
+ Revision: 334154
- Update to 1.7.8

* Sat Dec 01 2012 philippem <philippem> 1.7.6-1.mga3
+ Revision: 324146
- update to 1.7.6
+ malo <malo>
- update RPM group

* Sun Sep 30 2012 fwang <fwang> 1.7.4-2.mga3
+ Revision: 300677
- update python abi support

* Sat Sep 29 2012 fwang <fwang> 1.7.4-1.mga3
+ Revision: 300351
- new version 1.7.4

* Sat Sep 29 2012 fwang <fwang> 1.7.0-2.mga3
+ Revision: 300310
- rebuild for new py 3.3

* Thu Aug 02 2012 kamil <kamil> 1.7.0-1.mga3
+ Revision: 278018
- new version 1.7.0

* Tue Jul 03 2012 kamil <kamil> 1.7.0-0.pre5.3.mga3
+ Revision: 267032
- split waf.macros into python2 and python3 version and package separately

* Mon Jul 02 2012 kamil <kamil> 1.7.0-0.pre5.2.mga3
+ Revision: 266838
- stop using want-rpath=0 parameter in waf.macros, it's not standard and interrupts build

* Mon Jul 02 2012 kamil <kamil> 1.7.0-0.pre5.1.mga3
+ Revision: 266582
- new version 1.7.0pre5

* Sat Jun 30 2012 kamil <kamil> 1.6.11-2.mga3
+ Revision: 265669
- add support for python3-waf in .macro

* Sat Jun 30 2012 kamil <kamil> 1.6.11-1.mga3
+ Revision: 265577
- new version 1.6.11
- add subpackage with the Python 3 build (inspired by Fedora)
- clean .spec a bit

* Tue Dec 20 2011 philippem <philippem> 1.6.10-1.mga2
+ Revision: 184943
- Update to 1.6.10
- Remove patch applied upstream
- Change summary

* Wed Nov 30 2011 philippem <philippem> 1.6.9-1.mga2
+ Revision: 174541
- Update to 1.6.9

* Sat Oct 22 2011 philippem <philippem> 1.6.8-1.mga2
+ Revision: 157381
- Update to 1.6.8.
- Move HTML documentation to a subpackage.

* Sat Feb 26 2011 philippem <philippem> 1.6.3-2.mga1
+ Revision: 61039
- remove not allowed docs (bad licence)

* Sat Feb 26 2011 philippem <philippem> 1.6.3-1.mga1
+ Revision: 60933
- imported package waf

